@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import sys
 from collections import defaultdict
@@ -7,12 +9,10 @@ from urllib.parse import urlparse
 
 from typing_extensions import Any
 
-from patchwork.common.utils import count_openai_tokens, open_with_chardet
+from patchwork.common.context_strategy.context_strategies import ContextStrategies
+from patchwork.common.utils.utils import count_openai_tokens, open_with_chardet
 from patchwork.logger import logger
 from patchwork.step import Step
-from patchwork.steps.ExtractCode.context_strategy.context_strategies import (
-    ContextStrategies,
-)
 
 
 def get_source_code_context(
@@ -21,15 +21,15 @@ def get_source_code_context(
     context_strategies = ContextStrategies.get_context_strategies(*ContextStrategies.ALL)
     context_strategies = [strategy for strategy in context_strategies if strategy.is_file_supported(uri, source_lines)]
     for context_strategy in context_strategies:
-        context_start, context_end = context_strategy.get_context_indexes(source_lines, start_line, end_line)
-        if context_start is None or context_end is None:
-            logger.info(f'Context Strategy: "{context_strategy.__class__.__name__}" failed to return context')
+        position = context_strategy.get_context_indexes(source_lines, start_line, end_line)
+        if position is None:
+            logger.debug(f'Context Strategy: "{context_strategy.__class__.__name__}" failed to return context')
             continue
 
-        logger.info(f'"{context_strategy.__class__.__name__}" Context Strategy used: {context_start}, {context_end}')
-        context = "".join(source_lines[context_start:context_end])
+        logger.debug(f'"{context_strategy.__class__.__name__}" Context Strategy used: {position.start}, {position.end}')
+        context = "".join(source_lines[position.start : position.end])
         if count_openai_tokens(context) <= context_token_length:
-            return context_start, context_end
+            return position.start, position.end
 
     return None, None
 
@@ -41,7 +41,7 @@ def parse_sarif_location(base_path: Path, location_str: str) -> Path | None:
         return None
 
     path = Path(uri.path)
-    if path.is_relative_to(base_path):
+    if not os.path.relpath(path.resolve(), base_path.resolve()).startswith(".."):
         return path
 
     path = str(path).lstrip("/")
@@ -211,7 +211,7 @@ def transform_sarif_results(
                 file_path = str(uri.relative_to(base_path))
 
                 # Extract lines from the code file
-                logger.info(f"Extracting context for {file_path} at {start_line}:{end_line}")
+                logger.debug(f"Extracting context for {file_path} at {start_line}:{end_line}")
                 try:
                     with open_with_chardet(file_path, "r") as file:
                         src = file.read()
@@ -229,10 +229,10 @@ def transform_sarif_results(
                     context_start = None
                     context_end = None
                     source_code_context = None
-                    logger.info(f"File not found in the current working directory: {file_path}")
+                    logger.debug(f"File not found in the current working directory: {file_path}")
 
                 if source_code_context is None:
-                    logger.info(f"No context found for {file_path} at {start_line}:{end_line}")
+                    logger.debug(f"No context found for {file_path} at {start_line}:{end_line}")
                     continue
 
                 start = context_start if context_start is not None else start_line
@@ -289,5 +289,4 @@ class ExtractCode(Step):
 
         return dict(
             files_to_patch=self.extracted_code_contexts,
-            prompt_values=self.extracted_code_contexts,
         )
