@@ -1,13 +1,12 @@
 from __future__ import annotations
 
-from typing_extensions import Annotated, TypedDict
+from typing_extensions import TypedDict, Annotated
 
-from patchwork.common.utils.types import IS_CONFIG
+from patchwork.common.utils.typing import IS_PATH
 
 
 class ExtractCodeMethodForCommentContextsInputs(TypedDict):
-    base_path: Annotated[str, IS_CONFIG]
-    context_grouping: Annotated[str, IS_CONFIG]
+    base_path: Annotated[str, IS_PATH]
 
 
 class ExtractCodeMethodForCommentContextsOutputs(TypedDict):
