@@ -1,9 +1,11 @@
-from typing_extensions import Iterable, TypedDict
+from __future__ import annotations
+
+from typing_extensions import TypedDict
 
 
 class ModifyCodeInputs(TypedDict):
-    code_file: str
-    extracted_responses: Iterable[dict[str, str]]
+    files_to_patch: list[dict]
+    extracted_responses: list[dict[str, str]]
 
 
 class ModifyCodeOutputs(TypedDict):
